@@ -3,7 +3,7 @@ from .components import (
     Readability,
     DependencyDistance,
     DescriptiveStatistics,
-    POSStatistics
+    POSStatistics,
 )
 
 from spacy.language import Language
@@ -16,7 +16,7 @@ def create_textdescriptives_component(nlp: Language, name: str):
         "descriptive_stats",
         "readability",
         "dependency_distance",
-        "pos_stats"
+        "pos_stats",
     ]:
         nlp.add_pipe(component, last=True)
     return TextDescriptives(nlp)
